import { Browser, BrowserConnectOptions, BrowserLaunchArgumentOptions, LaunchOptions as PPTLaunchOptions, Page, Product } from 'puppeteer';
import { UserFlow } from 'lighthouse/lighthouse-core/fraggle-rock/user-flow';
import FlowResult from 'lighthouse/types/lhr/flow';
export { UserFlowRcConfig } from '../internal/config/model';
export declare type LaunchOptions = PPTLaunchOptions & BrowserLaunchArgumentOptions & BrowserConnectOptions & {
    product?: Product;
    extraPrefsFirefox?: Record<string, unknown>;
};
export interface UserFlowOptions {
    name: string;
}
/**
 * used inside of `UserFlowInteractionsFn`
 */
export interface StepOptions {
    stepName: string;
}
export declare type UserFlowContext = {
    browser: Browser;
    page: Page;
    flow: UserFlow;
    collectOptions: {
        url: string;
    };
};
export declare type UserFlowInteractionsFn = (context: UserFlowContext) => Promise<void>;
export declare type UserFlowProvider = {
    flowOptions: UserFlowOptions;
    interactions: UserFlowInteractionsFn;
    launchOptions?: LaunchOptions;
};
/**
 * This class is used in the user-flow interactions to ensure the context of the flow is available in UFO's
 */
export declare class Ufo {
    protected page: Page;
    constructor({ page }: UserFlowContext);
}
/**
 * @TODO this is very flakey ATM and needs investigation
 */
export declare class UserFlowMock {
    protected page: Page;
    /**
     * @param {LH.NavigationRequestor} requestor
     * @param {StepOptions=} stepOptions
     */
    navigate(requestor: any, { stepName }?: StepOptions): Promise<any>;
    constructor(page: Page, { name }: UserFlowOptions);
    /**
     * @param {StepOptions=} stepOptions
     */
    startTimespan({ stepName }?: StepOptions): Promise<void>;
    endTimespan({ stepName }?: StepOptions): Promise<void>;
    /**
     * @param {StepOptions=} stepOptions
     */
    snapshot({ stepName }?: StepOptions): Promise<void>;
    /**
     * @return {LH.FlowResult}
     */
    getFlowResult(): FlowResult;
    /**
     * @return {Promise<string>}
     */
    generateReport(): Promise<string>;
}
